//    Persistence of Vision Ray Tracer version 3.5 Include File
//    File: rad_def.inc
//    Last updated: 2001.7.26
//    Description: Set some common radiosity settings.
// These settings are extremely general and are intended for
// ease of use, and don't necessarily give the best results.

//Modified 2001.7.26: Made Normal and Media parameters work
//no matter what setting is used. (Chris Huff)

#ifndef(Rad_Def2_Inc_Temp)
#declare Rad_Def2_Inc_Temp = version;
#version 3.5;

#ifdef(View_POV_Include_Stack)
    #debug "including rad_def.inc\n"
#end

#declare Radiosity_Default = 0;
#declare Radiosity_OutdoorFast = 1;
#declare Radiosity_IndoorFast = 2;
#declare Radiosity_OutdoorLQ = 3;
#declare Radiosity_IndoorLQ = 4;
#declare Radiosity_OutdoorLight = 5;
#declare Radiosity_IndoorLight = 6;
#declare Radiosity_OutdoorHQ = 7;
#declare Radiosity_IndoorHQ = 8;
#declare Radiosity_OutdoorFinal = 9;
#declare Radiosity_IndoorFinal = 10;
#declare Radiosity_Normal = 11;



// The correct format for using this file is:
//
// #include "rad_def.inc"
// global_settings {
//   radiosity {
//     Rad_Settings(Radiosity_Default, off, off)
//   }
// }
//
// ####### DON NOT FORGET TO USE THE +QR/Radiosity=on OPTION ########
//
// for first parameter use one of the above constants
//
// second parameter for radiosity normal switch
// (turn 'on' if normal should be taken into account when calculating radiosity)
//
// third parameter for radiosity media switch
// (turn 'on' if media should be taken into account when calculating radiosity)
//


#macro Rad_Settings(Nbr, Normal, Media)

  #switch(Nbr)

    // 0: An empty raddiosiy block uses deault settings
    #case (Radiosity_Default)
    #debug "\nRadiosity_Default in use\n"
    #break

    // 1: Make it look as good as you can, but I'm in a hurry
    #case (Radiosity_OutdoorFast)
      pretrace_start 0.08
      pretrace_end   0.02
      count 50
      nearest_count 5
      error_bound 0.8
      recursion_limit 1
      low_error_factor 0.9
      gray_threshold 0.8
      minimum_reuse 0.025
      adc_bailout 0.01/2
    #break
	
	// 2: Make it look as good as you can, but I'm in a hurry
	#case (Radiosity_IndoorFast)
      pretrace_start 0.08
      pretrace_end   0.02
      count 60
      nearest_count 5
      error_bound 0.8
      recursion_limit 1
      low_error_factor 0.9
      gray_threshold 0
      minimum_reuse 0.025
      adc_bailout 0.01/2
    #break
	  
	 // 3: For outdoor scenes without light sources
    // Low quality being reasonably fast in most scenes
    #case (Radiosity_OutdoorLQ)
      pretrace_start 0.08
      pretrace_end   0.01
      count 100
      nearest_count 4
      error_bound 0.6
      recursion_limit 2      // increase this in scenes with complicated geometries when necessary
      low_error_factor 0.8
      gray_threshold 0.6
      minimum_reuse 0.015
      adc_bailout 0.01/2
    #break
	
	 // 4: quite fast settings for indoor radiosity
    // good values much depend on actual situation
    // these settings can be taken as a basis
    #case (Radiosity_IndoorLQ)
      pretrace_start 0.08
      pretrace_end   0.01
      count 140
      nearest_count 5
      error_bound 0.7
      recursion_limit 2
      low_error_factor 0.8
      gray_threshold 0.1
      minimum_reuse 0.015
      adc_bailout 0.01/2
    #break
	
	 // 5: Settings for outdoor scenes with (Sun)light
    // for getting a general skylight effect
    #case (Radiosity_OutdoorLight)
      pretrace_start 0.08
      pretrace_end   0.01
      count 150
      nearest_count 4
      error_bound 0.7
      recursion_limit 1
      low_error_factor 0.9
      gray_threshold 0.5
      minimum_reuse 0.015
      adc_bailout 0.01/2
    #break
	
	 // 6: Settings for indoor scenes with (Sun)light
    // for getting a general skylight effect
    #case (Radiosity_IndoorLight)
      pretrace_start 0.08
      pretrace_end   0.01
      count 180
      nearest_count 4
      error_bound 0.6
      recursion_limit 1
      low_error_factor 0.9
      gray_threshold 0.2
      minimum_reuse 0.015
      adc_bailout 0.01/2
    #break
	 
	 // 7: For outdoor scenes without light sources
    // High quality - can be very slow
    #case (Radiosity_OutdoorHQ)
      pretrace_start 0.08
      pretrace_end   0.004
      count 500
      nearest_count 7
      error_bound 0.4
      recursion_limit 2      // increase this in scenes with complicated geometries when necessary
      low_error_factor 0.5
      gray_threshold 0.15
      minimum_reuse 0.015
      adc_bailout 0.01/2
    #break
	
	 // 8: slower settings for indoor radiosity
    // good values much depend on actual situation
    // these settings can be taken as a basis
    #case (Radiosity_IndoorHQ)
      pretrace_start 0.08
      pretrace_end   0.004
      count 550
      nearest_count 8
      error_bound 0.3
      recursion_limit 3
      low_error_factor 0.5
      gray_threshold 0.1
      minimum_reuse 0.015
      adc_bailout 0.01/2
    #break
	 
	 // 9: For patient quality freaks with fast computers about to leave on vacation
    #case (Radiosity_OutdoorFinal)
      pretrace_start 0.08
      pretrace_end   0.005
      count 800
      nearest_count 9
      error_bound 0.2
      recursion_limit 1
      low_error_factor 0.7
      gray_threshold 0.1
      minimum_reuse 0.01
      adc_bailout 0.01/2
    #break
	 
	 // 10: For patient quality freaks with fast computers about to leave on vacation
    #case (Radiosity_IndoorFinal)
      pretrace_start 0.08
      pretrace_end   0.005
      count 850
      nearest_count 9
      error_bound 0.2
      recursion_limit 1
      low_error_factor 0.7
      gray_threshold 0
      minimum_reuse 0.01
      adc_bailout 0.01/2
    #break
	
    // 11: Typical values
    #case (Radiosity_Normal)
      pretrace_start 0.08
      pretrace_end   0.01
      count 200
      nearest_count 7
      error_bound 0.5
      recursion_limit 1
      low_error_factor 0.75
      gray_threshold 0
      minimum_reuse 0.017
      brightness 1.0
      adc_bailout 0.01/2
    #break
#end

    normal Normal
    media Media
#end

#version Rad_Def2_Inc_Temp;
#end
